@@ -3,15 +3,14 @@ package Test::Alien::CanCompileCpp;
 use strict;
 use warnings;
 use base 'Test2::Require';
+use ExtUtils::CBuilder 0.27;
 
 # ABSTRACT: Skip a test file unless a C++ compiler is available
-our $VERSION = '1.00_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 sub skip
 {
-  require ExtUtils::CBuilder;
   ExtUtils::CBuilder->new->have_cplusplus ? undef : 'This test requires a compiler.';
 }
 
@@ -29,7 +28,7 @@ Test::Alien::CanCompileCpp - Skip a test file unless a C++ compiler is available
 
 =head1 VERSION
 
-version 1.00_01
+version 1.01
 
 =head1 SYNOPSIS
 
